%Creates a statistic 'Unique track color' that is the same for all surfaces
%of a given track. This allows surfaces to be color coded based on which
%track they belong to, for the purposes of visualizing and differentiating 
%the the movement of many differnet surface objects of the same type

clc
clear
javaaddpath ImarisLib.jar;
vImarisLib = ImarisLib;
imaris = vImarisLib.GetApplication(0);
dataset = imaris.GetDataSet;
surpass = imaris.GetSurpassScene;

%get currently selected surfaces
% surface = imaris.GetFactory.ToSurfaces(imaris.GetSurpassSelection);
%get bottom one
surface = imaris.GetFactory.ToSurfaces(imaris.GetSurpassSelection);
trackEdges = surface.GetTrackEdges;
trackIDs = surface.GetTrackIds;

%make map of track indices to surf indices
trackMap = containers.Map(1,[1 1]);
remove(trackMap,1);

for i = 1:length(trackIDs)
    if (isKey(trackMap,trackIDs(i)))
        %add new keys
        existingValues = trackMap(trackIDs(i));
        newValues = trackEdges(i,:);
        trackMap(trackIDs(i)) = unique([existingValues newValues]);
    else
        %add key
        trackMap(trackIDs(i)) = trackEdges(i,:);
    end
end

%now go through all tracks and add custom statistics for each one
surfIDs = values(trackMap);
statVals =[];
ids = [];
for i = 1: length(surfIDs)
    ids = [ids surfIDs{i}];
    val = rand;
    statVals = [statVals val*ones(1,length(surfIDs{i}))];
end

statNames = repmat({'Unique track color'},size(statVals));
statUnits = repmat({'no unit'},size(statVals));
statFactors = cell(3, length(statVals));
statFactors(1, :) = repmat({'Surface'}, size(statVals));
statFactors(2, :) = repmat({''}, size(statVals));
% statFactors(3, :) = objectTimeIdxs;
factorNames = {'Category'; 'Collection'; 'Time'};

imaris.GetSurpassSelection.AddStatistics(statNames,statVals,statUnits,statFactors,factorNames,ids);